import Link from 'next/link';
import type { FileItem } from '@/types';
import { Card, CardContent, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { format } from 'date-fns';
import { Eye, DownloadCloud } from 'lucide-react';
import { FileTypeIcon } from '@/components/icons/FileTypeIcon';

interface FileListItemProps {
  file: FileItem;
}

function formatFileSize(bytes: number): string {
  if (bytes === 0) return '0 Bytes';
  const k = 1024;
  const sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
  const i = Math.floor(Math.log(bytes) / Math.log(k));
  return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
}

export default function FileListItem({ file }: FileListItemProps) {
  return (
    <Card className="flex flex-col group hover:shadow-lg transition-shadow duration-300 ease-in-out transform hover:-translate-y-1">
      <CardHeader className="pb-3">
        <div className="flex items-center space-x-3">
          <FileTypeIcon fileType={file.type} extension={file.extension} className="w-8 h-8 text-primary" />
          <CardTitle className="text-lg leading-tight truncate font-medium" title={file.name}>
            {file.name}
          </CardTitle>
        </div>
      </CardHeader>
      <CardContent className="flex-grow space-y-2 text-sm text-muted-foreground">
        <p>Size: {formatFileSize(file.size)}</p>
        <p>Uploaded: {format(new Date(file.uploadDate), "MMM d, yyyy 'at' h:mm a")}</p>
      </CardContent>
      <CardFooter className="pt-3">
        <Button variant="outline" size="sm" asChild className="w-full">
          <Link href={file.url} className="flex items-center">
            <Eye className="mr-2 h-4 w-4" />
            View Details
          </Link>
        </Button>
        {/* Actual download would require a different setup. This is a placeholder. */}
        {/* <Button variant="ghost" size="sm" className="ml-2">
          <DownloadCloud className="h-4 w-4" />
        </Button> */}
      </CardFooter>
    </Card>
  );
}
