
import Link from 'next/link';
import { AppLogo } from '@/components/core/AppLogo';
import { Button } from '@/components/ui/button';
import { isAuthenticated } from '@/lib/auth';
import { logoutAction } from '@/lib/actions/auth.actions';
import { UploadCloud, LogOut, LogIn, LayoutGrid } from 'lucide-react';

export default async function Header() {
  const authenticated = await isAuthenticated();

  return (
    <header className="sticky top-0 z-50 w-full border-b border-border/40 bg-background/95 backdrop-blur supports-[backdrop-filter]:bg-background/60">
      <div className="container mx-auto flex h-16 items-center justify-between px-6 md:px-8 lg:px-10">
        <Link href="/" className="flex items-center space-x-2" aria-label="VividCDN Home">
          <AppLogo />
        </Link>
        <nav className="flex-shrink-0 flex items-center space-x-1 sm:space-x-3">
          {authenticated && (
            <>
              <Button variant="ghost" asChild>
                <Link href="/browse" className="flex items-center">
                  <LayoutGrid className="mr-0 sm:mr-2 h-5 w-5" />
                  <span className="hidden sm:inline">Browse</span>
                </Link>
              </Button>
              <Button variant="ghost" asChild>
                <Link href="/upload" className="flex items-center">
                  <UploadCloud className="mr-0 sm:mr-2 h-5 w-5" />
                   <span className="hidden sm:inline">Upload</span>
                </Link>
              </Button>
              <form action={logoutAction}>
                <Button variant="ghost" type="submit" className="flex items-center">
                  <LogOut className="mr-0 sm:mr-2 h-5 w-5" />
                   <span className="hidden sm:inline">Logout</span>
                </Button>
              </form>
            </>
          )}
          {!authenticated && (
            <Button asChild>
              <Link href="/login" className="flex items-center">
                <LogIn className="mr-2 h-5 w-5" />
                Login
              </Link>
            </Button>
          )}
        </nav>
      </div>
    </header>
  );
}
