import {
  File,
  FileImage,
  FileText,
  FileVideo,
  Music, // Lucide doesn't have FileAudio, Music is a good alternative
  Archive,
  FileCode2, // Lucide doesn't have FileCode, FileCode2 is available
  FileSpreadsheet,
  FileJson2, // Lucide doesn't have FileJson, FileJson2 is available
  FileQuestion,
  LucideProps,
} from 'lucide-react';
import type { FileItem } from '@/types';

interface FileTypeIconProps extends LucideProps {
  fileType: FileItem['type'];
  extension: FileItem['extension'];
}

const iconMapping: Record<string, React.ElementType<LucideProps>> = {
  // MIME type based
  'image': FileImage,
  'application/pdf': FileText,
  'text': FileText,
  'video': FileVideo,
  'audio': Music,
  'application/zip': Archive,
  'application/x-rar-compressed': Archive,
  'application/x-tar': Archive,
  'application/gzip': Archive,
  'application/json': FileJson2,
  'application/vnd.ms-excel': FileSpreadsheet,
  'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet': FileSpreadsheet,
  // Extension based
  'doc': FileText,
  'docx': FileText,
  'txt': FileText,
  'md': FileText,
  'rtf': FileText,
  'csv': FileSpreadsheet,
  'xls': FileSpreadsheet,
  'xlsx': FileSpreadsheet,
  'ppt': FileText, // Placeholder, could be PresentationIcon if available
  'pptx': FileText,
  'html': FileCode2,
  'css': FileCode2,
  'js': FileCode2,
  'ts': FileCode2,
  'py': FileCode2,
  'java': FileCode2,
  'c': FileCode2,
  'cpp': FileCode2,
  'cs': FileCode2,
  'php': FileCode2,
  'rb': FileCode2,
  'go': FileCode2,
  'swift': FileCode2,
  'kt': FileCode2,
  'sql': FileCode2,
};

export function FileTypeIcon({ fileType, extension, className, ...props }: FileTypeIconProps) {
  let IconComponent = iconMapping[extension] || iconMapping[fileType.split('/')[0]] || File;
  
  if (fileType.startsWith('image/')) IconComponent = FileImage;
  else if (fileType.startsWith('video/')) IconComponent = FileVideo;
  else if (fileType.startsWith('audio/')) IconComponent = Music;
  else if (fileType === 'application/pdf') IconComponent = FileText;
  else if (extension === 'unknown' && fileType === 'application/octet-stream') IconComponent = FileQuestion;


  return <IconComponent className={className} {...props} />;
}
