"use server";

import { cookies } from 'next/headers';
import { redirect } from 'next/navigation';
import bcrypt from 'bcryptjs';
import { ADMIN_USERNAME, ADMIN_PASSWORD_HASH, AUTH_COOKIE_NAME } from '@/lib/constants';
import { z } from 'zod';

const loginSchema = z.object({
  username: z.string().min(1, "Username is required"),
  password: z.string().min(1, "Password is required"),
});

export async function loginAction(prevState: any, formData: FormData) {
  try {
    const validatedFields = loginSchema.safeParse(Object.fromEntries(formData.entries()));

    if (!validatedFields.success) {
      return {
        message: "Invalid fields. " + validatedFields.error.flatten().fieldErrors.username?.[0] || validatedFields.error.flatten().fieldErrors.password?.[0] || "",
      };
    }
    
    const { username, password } = validatedFields.data;

    if (username === ADMIN_USERNAME && await bcrypt.compare(password, ADMIN_PASSWORD_HASH)) {
      cookies().set(AUTH_COOKIE_NAME, 'true', {
        httpOnly: true,
        secure: process.env.NODE_ENV === 'production',
        maxAge: 60 * 60 * 24 * 7, // 1 week
        path: '/',
        sameSite: 'lax',
      });
    } else {
      return { message: 'Invalid username or password' };
    }
  } catch (error) {
    return { message: 'An unexpected error occurred. Please try again.' };
  }
  redirect('/browse');
}

export async function logoutAction() {
  cookies().delete(AUTH_COOKIE_NAME);
  redirect('/login');
}
